"""This module contains the meta information of ComputeGetServerCatalog ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ComputeGetServerCatalog", "computeGetServerCatalog", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_domain_group_list": MethodPropertyMeta("InDomainGroupList", "inDomainGroupList", "DnSet", "Version142b", "Input", True),
    "in_equipment_filter": MethodPropertyMeta("InEquipmentFilter", "inEquipmentFilter", "ConfigConfig", "Version142b", "Input", True),
    "in_exclude_total_result_size": MethodPropertyMeta("InExcludeTotalResultSize", "inExcludeTotalResultSize", "Xs:string", "Version142b", "Input", False),
    "in_filter": MethodPropertyMeta("InFilter", "inFilter", "FilterFilter", "Version142b", "Input", True),
    "in_include_filter_list_only": MethodPropertyMeta("InIncludeFilterListOnly", "inIncludeFilterListOnly", "Xs:string", "Version142b", "Input", False),
    "in_include_props": MethodPropertyMeta("InIncludeProps", "inIncludeProps", "Xs:string", "Version142b", "Input", False),
    "in_limit": MethodPropertyMeta("InLimit", "inLimit", "Xs:unsignedShort", "Version142b", "Input", False),
    "in_offset": MethodPropertyMeta("InOffset", "inOffset", "Xs:unsignedShort", "Version142b", "Input", False),
    "in_recursive": MethodPropertyMeta("InRecursive", "inRecursive", "Xs:string", "Version142b", "Input", False),
    "in_return_count_only": MethodPropertyMeta("InReturnCountOnly", "inReturnCountOnly", "Xs:string", "Version142b", "Input", False),
    "out_catalog": MethodPropertyMeta("OutCatalog", "outCatalog", "ConfigSet", "Version142b", "Output", True),
    "out_filter_list": MethodPropertyMeta("OutFilterList", "outFilterList", "ConfigSet", "Version142b", "Output", True),
    "out_has_more_results": MethodPropertyMeta("OutHasMoreResults", "outHasMoreResults", "Xs:string", "Version142b", "Output", False),
    "out_result_set_size": MethodPropertyMeta("OutResultSetSize", "outResultSetSize", "Xs:unsignedInt", "Version142b", "Output", False),
    "out_total_result_set_size": MethodPropertyMeta("OutTotalResultSetSize", "outTotalResultSetSize", "Xs:unsignedInt", "Version142b", "Output", False),
}

prop_map = {
    "cookie": "cookie",
    "inDomainGroupList": "in_domain_group_list",
    "inEquipmentFilter": "in_equipment_filter",
    "inExcludeTotalResultSize": "in_exclude_total_result_size",
    "inFilter": "in_filter",
    "inIncludeFilterListOnly": "in_include_filter_list_only",
    "inIncludeProps": "in_include_props",
    "inLimit": "in_limit",
    "inOffset": "in_offset",
    "inRecursive": "in_recursive",
    "inReturnCountOnly": "in_return_count_only",
    "outCatalog": "out_catalog",
    "outFilterList": "out_filter_list",
    "outHasMoreResults": "out_has_more_results",
    "outResultSetSize": "out_result_set_size",
    "outTotalResultSetSize": "out_total_result_set_size",
}




"""This module contains the general information for EquipmentCPMeta ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentCPMetaConsts():
    CP_REFRESH_DISABLED = "disabled"
    CP_REFRESH_ENABLED = "enabled"
    IS_RENAME_FALSE = "false"
    IS_RENAME_NO = "no"
    IS_RENAME_TRUE = "true"
    IS_RENAME_YES = "yes"
    NEED_ID_RE_EVALUATE_NO = "no"
    NEED_ID_RE_EVALUATE_YES = "yes"
    OPERATION_CODE_ASSOCIATE = "associate"
    OPERATION_CODE_DELETION = "deletion"
    OPERATION_CODE_DISASSOCIATE = "disassociate"
    OPERATION_CODE_NO_OP = "no-op"
    OPERATION_CODE_RENAME = "rename"
    OPERATION_CODE_CLEARANCE_DISABLED = "disabled"
    OPERATION_CODE_CLEARANCE_ENABLED = "enabled"
    OWNERSHIP_STATE_DELETE_PENDING = "delete-pending"
    OWNERSHIP_STATE_DISASSOC_PENDING = "disassoc-pending"
    OWNERSHIP_STATE_GLOBAL_CONTROLLED = "global-controlled"
    OWNERSHIP_STATE_LOCALIZED = "localized"


class EquipmentCPMeta(ManagedObject):
    """This is EquipmentCPMeta class."""

    consts = EquipmentCPMetaConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentCPMeta", "equipmentCPMeta", "cpmeta", VersionMeta.Version151a, "InputOutput", 0x3f, [], ["admin", "pn-equipment", "pn-maintenance", "pn-policy"], ['equipmentChassisProfile'], ['messageEp'], ["Get"])

    prop_meta = {
        "chassis_dn": MoPropertyMeta("chassis_dn", "chassisDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_qualifier": MoPropertyMeta("config_qualifier", "configQualifier", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|not-applicable),){0,1}(defaultValue|not-applicable){0,1}""", [], []), 
        "cp_refresh": MoPropertyMeta("cp_refresh", "cpRefresh", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["disabled", "enabled"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "guid": MoPropertyMeta("guid", "guid", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "is_rename": MoPropertyMeta("is_rename", "isRename", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "need_id_re_evaluate": MoPropertyMeta("need_id_re_evaluate", "needIdReEvaluate", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "new_cpdn": MoPropertyMeta("new_cpdn", "newCPDN", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "old_cpdn": MoPropertyMeta("old_cpdn", "oldCPDN", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "operation_code": MoPropertyMeta("operation_code", "operationCode", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["associate", "deletion", "disassociate", "no-op", "rename"], []), 
        "operation_code_clearance": MoPropertyMeta("operation_code_clearance", "operationCodeClearance", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["disabled", "enabled"], []), 
        "ownership_state": MoPropertyMeta("ownership_state", "ownershipState", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["delete-pending", "disassoc-pending", "global-controlled", "localized"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "chassisDn": "chassis_dn", 
        "childAction": "child_action", 
        "configQualifier": "config_qualifier", 
        "cpRefresh": "cp_refresh", 
        "dn": "dn", 
        "guid": "guid", 
        "isRename": "is_rename", 
        "needIdReEvaluate": "need_id_re_evaluate", 
        "newCPDN": "new_cpdn", 
        "oldCPDN": "old_cpdn", 
        "operationCode": "operation_code", 
        "operationCodeClearance": "operation_code_clearance", 
        "ownershipState": "ownership_state", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.chassis_dn = None
        self.child_action = None
        self.config_qualifier = None
        self.cp_refresh = None
        self.guid = None
        self.is_rename = None
        self.need_id_re_evaluate = None
        self.new_cpdn = None
        self.old_cpdn = None
        self.operation_code = None
        self.operation_code_clearance = None
        self.ownership_state = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentCPMeta", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import *
from ..connection.info import *
from ucscsdk.mometa.fabric.FabricLanCloud import FabricLanCloud
from ucscsdk.mometa.fabric.FabricVlan import FabricVlan

handle = None
vlan_id = "100"
vlan_name = "test_vlan100"


def setup():
    global handle
    handle = custom_setup()


def teardown():
    custom_teardown(handle)


@with_setup(setup, teardown)
def test_001_create_modify_vlan_global():
    global vlan_id, vlan_name
    mo = FabricLanCloud(parent_mo_or_dn="domaingroup-root/fabric/lan", mode="end-host",
                        vlan_compression="disabled", mac_aging="mode-default")
    dn = handle.query_dn("domaingroup-root/fabric/lan")
    mo = FabricVlan(
        parent_mo_or_dn="domaingroup-root/fabric/lan", name=vlan_name)

    handle.remove_mo(mo)
    handle.commit()
    handle.add_mo(mo)
    handle.commit()

    obj = handle.query_dn("domaingroup-root/fabric/lan/net-" + vlan_name)
    obj.id = vlan_id
    handle.set_mo(obj)
    handle.commit()


@with_setup(setup, teardown)
def test_001_delete_vlan_global():
    global vlan_name
    obj = handle.query_dn("domaingroup-root/fabric/lan/net-" + vlan_name)
    handle.remove_mo(obj)
    handle.commit()



"""This module contains the general information for FirmwareSource ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FirmwareSourceConsts():
    DOWNLOAD_STATUS_FAILED = "failed"
    DOWNLOAD_STATUS_IDLE = "idle"
    DOWNLOAD_STATUS_INPROGRESS = "inprogress"
    LAST_DOWNLOAD_NEVER = "never"
    TRIGGER_STATE_NONE = "none"
    TRIGGER_STATE_TRIGGER_DELETE = "trigger-delete"
    TRIGGER_STATE_TRIGGER_DOWNLOAD = "trigger-download"
    TYPE_CISCO = "Cisco"
    TYPE_LOCAL = "local"


class FirmwareSource(ManagedObject):
    """This is FirmwareSource class."""

    consts = FirmwareSourceConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("FirmwareSource", "firmwareSource", "source-[type]", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["admin"], ['firmwareCatalogue'], ['faultInst', 'firmwareDownloadPolicy'], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "download_error": MoPropertyMeta("download_error", "downloadError", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "download_status": MoPropertyMeta("download_status", "downloadStatus", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["failed", "idle", "inprogress"], []), 
        "last_download": MoPropertyMeta("last_download", "lastDownload", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", ["never"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "trigger_state": MoPropertyMeta("trigger_state", "triggerState", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["none", "trigger-delete", "trigger-download"], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x20, None, None, None, ["Cisco", "local"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "downloadError": "download_error", 
        "downloadStatus": "download_status", 
        "lastDownload": "last_download", 
        "rn": "rn", 
        "status": "status", 
        "triggerState": "trigger_state", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.download_error = None
        self.download_status = None
        self.last_download = None
        self.status = None
        self.trigger_state = None

        ManagedObject.__init__(self, "FirmwareSource", parent_mo_or_dn, **kwargs)




"""This module contains the general information for TestingSnmpTrap ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class TestingSnmpTrapConsts():
    pass


class TestingSnmpTrap(ManagedObject):
    """This is TestingSnmpTrap class."""

    consts = TestingSnmpTrapConsts()
    naming_props = set(['hostname'])

    mo_meta = MoMeta("TestingSnmpTrap", "testingSnmpTrap", "snmp-trap-[hostname]", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["admin", "read-only"], ['testingSnmpSupport'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "community": MoPropertyMeta("community", "community", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, 0, 510, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "hostname": MoPropertyMeta("hostname", "hostname", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []), 
        "port": MoPropertyMeta("port", "port", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["1-65535"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "community": "community", 
        "dn": "dn", 
        "hostname": "hostname", 
        "port": "port", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, hostname, **kwargs):
        self._dirty_mask = 0
        self.hostname = hostname
        self.child_action = None
        self.community = None
        self.port = None
        self.status = None

        ManagedObject.__init__(self, "TestingSnmpTrap", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of ConfigCheckHardwareCompatibility ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigCheckHardwareCompatibility", "configCheckHardwareCompatibility", "Version142b")

prop_meta = {
    "class_id": MethodPropertyMeta("ClassId", "classId", "NamingClassId", "Version142b", "InputOutput", False),
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_target_blade_firmware_version": MethodPropertyMeta("InTargetBladeFirmwareVersion", "inTargetBladeFirmwareVersion", "Xs:string", "Version142b", "Input", False),
    "in_target_dn": MethodPropertyMeta("InTargetDn", "inTargetDn", "ReferenceObject", "Version142b", "Input", False),
    "in_target_modular_firmware_version": MethodPropertyMeta("InTargetModularFirmwareVersion", "inTargetModularFirmwareVersion", "Xs:string", "Version142b", "Input", False),
    "in_target_rack_firmware_version": MethodPropertyMeta("InTargetRackFirmwareVersion", "inTargetRackFirmwareVersion", "Xs:string", "Version142b", "Input", False),
    "in_target_ucs_firmware_version": MethodPropertyMeta("InTargetUCSFirmwareVersion", "inTargetUCSFirmwareVersion", "Xs:string", "Version142b", "Input", False),
    "out_cannot_determine_count": MethodPropertyMeta("OutCannotDetermineCount", "outCannotDetermineCount", "Xs:unsignedInt", "Version142b", "Output", False),
    "out_catalog_updated_date": MethodPropertyMeta("OutCatalogUpdatedDate", "outCatalogUpdatedDate", "Xs:string", "Version142b", "Output", False),
    "out_catalog_version": MethodPropertyMeta("OutCatalogVersion", "outCatalogVersion", "Xs:string", "Version142b", "Output", False),
    "out_configs": MethodPropertyMeta("OutConfigs", "outConfigs", "ConfigSet", "Version142b", "Output", True),
    "out_hc_error_desc": MethodPropertyMeta("OutHcErrorDesc", "outHcErrorDesc", "Xs:string", "Version142b", "Output", False),
    "out_not_supported_count": MethodPropertyMeta("OutNotSupportedCount", "outNotSupportedCount", "Xs:unsignedInt", "Version142b", "Output", False),
    "out_ok_count": MethodPropertyMeta("OutOkCount", "outOkCount", "Xs:unsignedInt", "Version142b", "Output", False),
    "out_total_count": MethodPropertyMeta("OutTotalCount", "outTotalCount", "Xs:unsignedInt", "Version142b", "Output", False),
}

prop_map = {
    "classId": "class_id",
    "cookie": "cookie",
    "inTargetBladeFirmwareVersion": "in_target_blade_firmware_version",
    "inTargetDn": "in_target_dn",
    "inTargetModularFirmwareVersion": "in_target_modular_firmware_version",
    "inTargetRackFirmwareVersion": "in_target_rack_firmware_version",
    "inTargetUCSFirmwareVersion": "in_target_ucs_firmware_version",
    "outCannotDetermineCount": "out_cannot_determine_count",
    "outCatalogUpdatedDate": "out_catalog_updated_date",
    "outCatalogVersion": "out_catalog_version",
    "outConfigs": "out_configs",
    "outHcErrorDesc": "out_hc_error_desc",
    "outNotSupportedCount": "out_not_supported_count",
    "outOkCount": "out_ok_count",
    "outTotalCount": "out_total_count",
}




"""This module contains the general information for FirmwareImage ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FirmwareImageConsts():
    ADMIN_STATE_ACTIVE = "active"
    ADMIN_STATE_DELETED = "deleted"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"


class FirmwareImage(ManagedObject):
    """This is FirmwareImage class."""

    consts = FirmwareImageConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("FirmwareImage", "firmwareImage", "image-[name]", VersionMeta.Version101a, "InputOutput", 0x7f, [], ["admin"], ['firmwareCatalogue', 'firmwareRemoteCatalogue'], [], ["Get", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["active", "deleted"], []), 
        "checksum": MoPropertyMeta("checksum", "checksum", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "download_date": MoPropertyMeta("download_date", "downloadDate", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "inv_tag": MoPropertyMeta("inv_tag", "invTag", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "isoname": MoPropertyMeta("isoname", "isoname", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "location": MoPropertyMeta("location", "location", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x10, 1, 128, None, [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "size": MoPropertyMeta("size", "size", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "version": MoPropertyMeta("version", "version", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "adminState": "admin_state", 
        "checksum": "checksum", 
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "downloadDate": "download_date", 
        "intId": "int_id", 
        "invTag": "inv_tag", 
        "isoname": "isoname", 
        "location": "location", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "size": "size", 
        "status": "status", 
        "version": "version", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.admin_state = None
        self.checksum = None
        self.child_action = None
        self.descr = None
        self.download_date = None
        self.int_id = None
        self.inv_tag = None
        self.isoname = None
        self.location = None
        self.policy_level = None
        self.policy_owner = None
        self.size = None
        self.status = None
        self.version = None

        ManagedObject.__init__(self, "FirmwareImage", parent_mo_or_dn, **kwargs)




"""This module contains the general information for BiosVfEnhancedIntelSpeedStepTech ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class BiosVfEnhancedIntelSpeedStepTechConsts():
    SUPPORTED_BY_DEFAULT_NO = "no"
    SUPPORTED_BY_DEFAULT_YES = "yes"
    VP_ENHANCED_INTEL_SPEED_STEP_TECH_DISABLED = "disabled"
    VP_ENHANCED_INTEL_SPEED_STEP_TECH_ENABLED = "enabled"
    VP_ENHANCED_INTEL_SPEED_STEP_TECH_PLATFORM_DEFAULT = "platform-default"
    VP_ENHANCED_INTEL_SPEED_STEP_TECH_PLATFORM_RECOMMENDED = "platform-recommended"


class BiosVfEnhancedIntelSpeedStepTech(ManagedObject):
    """This is BiosVfEnhancedIntelSpeedStepTech class."""

    consts = BiosVfEnhancedIntelSpeedStepTechConsts()
    naming_props = set([])

    mo_meta = MoMeta("BiosVfEnhancedIntelSpeedStepTech", "biosVfEnhancedIntelSpeedStepTech", "Enhanced-Intel-SpeedStep-Tech", VersionMeta.Version111a, "InputOutput", 0x1f, [], ["read-only"], ['biosVProfile'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "supported_by_default": MoPropertyMeta("supported_by_default", "supportedByDefault", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "yes"], []), 
        "vp_enhanced_intel_speed_step_tech": MoPropertyMeta("vp_enhanced_intel_speed_step_tech", "vpEnhancedIntelSpeedStepTech", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["disabled", "enabled", "platform-default", "platform-recommended"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "supportedByDefault": "supported_by_default", 
        "vpEnhancedIntelSpeedStepTech": "vp_enhanced_intel_speed_step_tech", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.status = None
        self.supported_by_default = None
        self.vp_enhanced_intel_speed_step_tech = None

        ManagedObject.__init__(self, "BiosVfEnhancedIntelSpeedStepTech", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StorageScsiLunRef ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageScsiLunRefConsts():
    ID_UNSPECIFIED = "unspecified"


class StorageScsiLunRef(ManagedObject):
    """This is StorageScsiLunRef class."""

    consts = StorageScsiLunRefConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("StorageScsiLunRef", "storageScsiLunRef", "scsi-lun-ref-[id]", VersionMeta.Version131a, "InputOutput", 0x1f, [], ["read-only"], ['storageLunReplica', 'storageLunSnapshot', 'storageScsiLun', 'storageVirtualDrive'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x4, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "ls_dn": MoPropertyMeta("ls_dn", "lsDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "lun_name": MoPropertyMeta("lun_name", "lunName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "pn_dn": MoPropertyMeta("pn_dn", "pnDn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "profile_dn": MoPropertyMeta("profile_dn", "profileDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "lsDn": "ls_dn", 
        "lunName": "lun_name", 
        "pnDn": "pn_dn", 
        "profileDn": "profile_dn", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.ls_dn = None
        self.lun_name = None
        self.pn_dn = None
        self.profile_dn = None
        self.status = None

        ManagedObject.__init__(self, "StorageScsiLunRef", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from ucscsdk.mometa.org.OrgDomainGroup import OrgDomainGroup
from ucscsdk.mometa.compute.ComputeSystemQual import ComputeSystemQual
from ucscsdk.mometa.compute.ComputeOwnerQual import ComputeOwnerQual
from nose.plugins.attrib import attr
from nose.tools import *
from ..connection.info import custom_setup, custom_teardown, \
    get_domain_params, skipped
domain_params = get_domain_params(1)
handle = None


def setup():
    global handle
    handle = custom_setup()


def teardown():
    custom_teardown(handle)


def test_001_create_domain_group():
    dom_grp_name = "new_test_domgrp"
    mo = OrgDomainGroup(parent_mo_or_dn="domaingroup-root", name=dom_grp_name)
    handle.remove_mo(mo)
    handle.commit()

    handle.add_mo(mo)
    handle.commit()
    found = False
    mo_list = handle.query_classid("orgDomainGroup")
    for i in range(0, len(mo_list)):
        if mo_list[i].name == dom_grp_name:
            found = True
            break

    assert_equal(found, True)
    handle.remove_mo(mo)
    handle.commit()


def test_002_create_domain_qual_policy():
    dom_qual_name = "new_dom_qual"
    dom_qual_mo = ComputeSystemQual(
        parent_mo_or_dn="org-root", name="new_dom_qual")
    handle.remove_mo(dom_qual_mo)
    handle.commit()

    handle.add_mo(dom_qual_mo)
    handle.commit()

    owner_name = "admin"
    mo = ComputeOwnerQual(parent_mo_or_dn="org-root/system-qualifier-" +
                          dom_qual_name, name=owner_name, regex="test_*")
    handle.add_mo(mo)
    handle.commit()
    obj = handle.query_dn("org-root/system-qualifier-" +
                          dom_qual_name + "/owner-" + owner_name)
    assert_equal(obj.regex, "test_*")

    handle.remove_mo(dom_qual_mo)
    handle.commit()


def test_003_domain_register():
    from ucscsdk.utils.ucscdomain import domain_register
    if domain_params is None:
        skipped("Arguments missing in config file")(
            test_003_domain_register)()
    domain_register(handle, domain_name_or_ip=domain_params[0]['ip'],
                    username=domain_params[0]['username'],
                    password=domain_params[0]['password'])


def test_004_domain_status():
    from ucscsdk.utils.ucscdomain import is_domain_registered, \
        get_domain_operational_status
    if domain_params is None:
        skipped("Arguments missing in config file")(
            test_004_domain_status)()
    if is_domain_registered(handle, domain_name_or_ip=domain_params[0]['ip']):
        print(get_domain_operational_status(handle, domain_params[0]['ip']))


@attr('config-disruptive')
def test_005_domain_unregister():
    from ucscsdk.utils.ucscdomain import domain_unregister
    if domain_params is None:
        skipped("Arguments missing in config file")(
            test_005_domain_unregister)()
    domain_unregister(handle, domain_params[0]['ip'])



"""This module contains the general information for IqnpoolTransportBlock ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class IqnpoolTransportBlockConsts():
    CONFIG_SCOPE_PRIVATE = "private"
    CONFIG_SCOPE_PUBLIC = "public"
    SCOPE_PRIVATE = "private"
    SCOPE_PUBLIC = "public"


class IqnpoolTransportBlock(ManagedObject):
    """This is IqnpoolTransportBlock class."""

    consts = IqnpoolTransportBlockConsts()
    naming_props = set(['suffix', 'from', 'to'])

    mo_meta = MoMeta("IqnpoolTransportBlock", "iqnpoolTransportBlock", "block-[suffix]-from-[r_from]-to-[to]", VersionMeta.Version112a, "InputOutput", 0xff, [], ["admin", "ls-storage-policy"], [], [], ["Get", "Set"])

    prop_meta = {
        "assigned": MoPropertyMeta("assigned", "assigned", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version112a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_scope": MoPropertyMeta("config_scope", "configScope", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["private", "public"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "r_from": MoPropertyMeta("r_from", "from", "ushort", VersionMeta.Version112a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], ["0-65535"]), 
        "qualifier": MoPropertyMeta("qualifier", "qualifier", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "scope": MoPropertyMeta("scope", "scope", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["private", "public"], []), 
        "size": MoPropertyMeta("size", "size", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suffix": MoPropertyMeta("suffix", "suffix", "string", VersionMeta.Version112a, MoPropertyMeta.NAMING, 0x40, None, None, r"""[0-9a-zA-Z\.:-]{0,64}$""", [], []), 
        "to": MoPropertyMeta("to", "to", "ushort", VersionMeta.Version112a, MoPropertyMeta.NAMING, 0x80, None, None, None, [], ["0-65535"]), 
    }

    prop_map = {
        "assigned": "assigned", 
        "childAction": "child_action", 
        "configScope": "config_scope", 
        "dn": "dn", 
        "from": "r_from", 
        "qualifier": "qualifier", 
        "rn": "rn", 
        "scope": "scope", 
        "size": "size", 
        "status": "status", 
        "suffix": "suffix", 
        "to": "to", 
    }

    def __init__(self, parent_mo_or_dn, suffix, r_from, to, **kwargs):
        self._dirty_mask = 0
        self.suffix = suffix
        self.r_from = r_from
        self.to = to
        self.assigned = None
        self.child_action = None
        self.config_scope = None
        self.qualifier = None
        self.scope = None
        self.size = None
        self.status = None

        ManagedObject.__init__(self, "IqnpoolTransportBlock", parent_mo_or_dn, **kwargs)




"""This module contains the general information for PowerBudget ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class PowerBudgetConsts():
    ADMIN_COMMITTED_UNBOUNDED = "unbounded"
    ADMIN_FPLOCK_STATE_LOCKED = "locked"
    ADMIN_FPLOCK_STATE_UNKNOWN = "unknown"
    ADMIN_FPLOCK_STATE_UNLOCKED = "unlocked"
    ADMIN_PEAK_UNBOUNDED = "unbounded"
    ADMIN_PEAK_NEW_UNBOUNDED = "unbounded"
    BOOT_POWER_UNBOUNDED = "unbounded"
    CAP_ACTION_CLOCK_DOWN = "clock-down"
    CAP_ACTION_NOTHING = "nothing"
    CAP_ACTION_THROTTLED = "throttled"
    CATALOG_POWER_UNBOUNDED = "unbounded"
    CH_RSRVD_POWER_UNBOUNDED = "unbounded"
    CURRENT_POWER_UNBOUNDED = "unbounded"
    DYN_REALLOC_CHASSIS = "chassis"
    DYN_REALLOC_NONE = "none"
    IDLE_POWER_UNBOUNDED = "unbounded"
    MAX_POWER_UNBOUNDED = "unbounded"
    MIN_POWER_UNBOUNDED = "unbounded"
    OPER_COMMITTED_UNBOUNDED = "unbounded"
    OPER_FPLOCK_STATE_LOCKED = "locked"
    OPER_FPLOCK_STATE_UNKNOWN = "unknown"
    OPER_FPLOCK_STATE_UNLOCKED = "unlocked"
    OPER_MIN_UNBOUNDED = "unbounded"
    OPER_PEAK_UNBOUNDED = "unbounded"
    OPER_PROF_METHOD_DEFAULT = "default"
    OPER_PROF_METHOD_NODEMGR = "nodemgr"
    OPER_PROF_METHOD_PNUOS = "pnuos"
    OPER_PROF_METHOD_STATIC = "static"
    OPER_PROF_METHOD_UNKNOWN = "unknown"
    OPER_STATE_BUDGETED = "budgeted"
    OPER_STATE_BUDGETING = "budgeting"
    OPER_STATE_DEPLOYED = "deployed"
    OPER_STATE_DEPLOYING = "deploying"
    OPER_STATE_DISCOVERY_BUDGETED = "discovery-budgeted"
    OPER_STATE_DISCOVERY_RETRY = "discovery-retry"
    OPER_STATE_FIRMWARE_MISMATCH = "firmware-mismatch"
    OPER_STATE_NON_COMPLIANT = "non-compliant"
    OPER_STATE_NOT_CAPPED = "not-capped"
    OPER_STATE_UNBUDGETED = "unbudgeted"
    POWER_AVAIL_STATE_AVAILABLE = "available"
    POWER_AVAIL_STATE_UNAVAILABLE = "unavailable"
    POWER_AVAIL_STATE_UNKNOWN = "unknown"
    POWER_ON_DEPLOY_FALSE = "false"
    POWER_ON_DEPLOY_NO = "no"
    POWER_ON_DEPLOY_TRUE = "true"
    POWER_ON_DEPLOY_YES = "yes"
    PRIO_NO_CAP = "no-cap"
    PRIO_UTILITY = "utility"
    PROF_METHOD_DEFAULT = "default"
    PROF_METHOD_NODEMGR = "nodemgr"
    PROF_METHOD_PNUOS = "pnuos"
    PROF_METHOD_STATIC = "static"
    PROF_METHOD_UNKNOWN = "unknown"
    PROFILING_FALSE = "false"
    PROFILING_NO = "no"
    PROFILING_TRUE = "true"
    PROFILING_YES = "yes"
    PSU_LINE_MODE_HIGH_LINE = "high-line"
    PSU_LINE_MODE_LOW_LINE = "low-line"
    PSU_LINE_MODE_MIXED_LINE = "mixed-line"
    PSU_LINE_MODE_UNDETERMINED = "undetermined"
    PSU_LINE_MODE_UNKNOWN = "unknown"
    PSU_STATE_INSUFFICIENT = "insufficient"
    PSU_STATE_OK = "ok"
    STYLE_INTELLIGENT_POLICY_DRIVEN = "intelligent-policy-driven"
    STYLE_MANUAL_PER_BLADE = "manual-per-blade"


class PowerBudget(ManagedObject):
    """This is PowerBudget class."""

    consts = PowerBudgetConsts()
    naming_props = set([])

    mo_meta = MoMeta("PowerBudget", "powerBudget", "budget", VersionMeta.Version131a, "InputOutput", 0x3f, [], ["admin", "power-mgmt"], ['computeExtBoard', 'storageBlade'], ['powerProfiledPower'], ["Get", "Set"])

    prop_meta = {
        "admin_committed": MoPropertyMeta("admin_committed", "adminCommitted", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "admin_fp_lock_state": MoPropertyMeta("admin_fp_lock_state", "adminFPLockState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["locked", "unknown", "unlocked"], []), 
        "admin_peak": MoPropertyMeta("admin_peak", "adminPeak", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "admin_peak_new": MoPropertyMeta("admin_peak_new", "adminPeakNew", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "boot_power": MoPropertyMeta("boot_power", "bootPower", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "cap_action": MoPropertyMeta("cap_action", "capAction", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["clock-down", "nothing", "throttled"], []), 
        "catalog_power": MoPropertyMeta("catalog_power", "catalogPower", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "ch_rsrvd_power": MoPropertyMeta("ch_rsrvd_power", "chRsrvdPower", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "current_power": MoPropertyMeta("current_power", "currentPower", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "dyn_realloc": MoPropertyMeta("dyn_realloc", "dynRealloc", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["chassis", "none"], []), 
        "group_name": MoPropertyMeta("group_name", "groupName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "idle_power": MoPropertyMeta("idle_power", "idlePower", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "max_power": MoPropertyMeta("max_power", "maxPower", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "min_power": MoPropertyMeta("min_power", "minPower", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "oper_committed": MoPropertyMeta("oper_committed", "operCommitted", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "oper_fp_lock_state": MoPropertyMeta("oper_fp_lock_state", "operFPLockState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["locked", "unknown", "unlocked"], []), 
        "oper_min": MoPropertyMeta("oper_min", "operMin", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "oper_peak": MoPropertyMeta("oper_peak", "operPeak", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unbounded"], ["0-10000000", "4294967295-4294967295"]), 
        "oper_prof_method": MoPropertyMeta("oper_prof_method", "operProfMethod", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["default", "nodemgr", "pnuos", "static", "unknown"], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["budgeted", "budgeting", "deployed", "deploying", "discovery-budgeted", "discovery-retry", "firmware-mismatch", "non-compliant", "not-capped", "unbudgeted"], []), 
        "power_avail_state": MoPropertyMeta("power_avail_state", "powerAvailState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["available", "unavailable", "unknown"], []), 
        "power_on_deploy": MoPropertyMeta("power_on_deploy", "powerOnDeploy", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "prio": MoPropertyMeta("prio", "prio", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no-cap", "utility"], ["1-10"]), 
        "prof_method": MoPropertyMeta("prof_method", "profMethod", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["default", "nodemgr", "pnuos", "static", "unknown"], []), 
        "profiling": MoPropertyMeta("profiling", "profiling", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "psu_capacity": MoPropertyMeta("psu_capacity", "psuCapacity", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-20000"]), 
        "psu_line_mode": MoPropertyMeta("psu_line_mode", "psuLineMode", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["high-line", "low-line", "mixed-line", "undetermined", "unknown"], []), 
        "psu_state": MoPropertyMeta("psu_state", "psuState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["insufficient", "ok"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "scaled_wt": MoPropertyMeta("scaled_wt", "scaledWt", "byte", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-200"]), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "style": MoPropertyMeta("style", "style", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["intelligent-policy-driven", "manual-per-blade"], []), 
        "update_time": MoPropertyMeta("update_time", "updateTime", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "weight": MoPropertyMeta("weight", "weight", "byte", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["0-200"]), 
    }

    prop_map = {
        "adminCommitted": "admin_committed", 
        "adminFPLockState": "admin_fp_lock_state", 
        "adminPeak": "admin_peak", 
        "adminPeakNew": "admin_peak_new", 
        "bootPower": "boot_power", 
        "capAction": "cap_action", 
        "catalogPower": "catalog_power", 
        "chRsrvdPower": "ch_rsrvd_power", 
        "childAction": "child_action", 
        "currentPower": "current_power", 
        "dn": "dn", 
        "dynRealloc": "dyn_realloc", 
        "groupName": "group_name", 
        "idlePower": "idle_power", 
        "maxPower": "max_power", 
        "minPower": "min_power", 
        "operCommitted": "oper_committed", 
        "operFPLockState": "oper_fp_lock_state", 
        "operMin": "oper_min", 
        "operPeak": "oper_peak", 
        "operProfMethod": "oper_prof_method", 
        "operState": "oper_state", 
        "powerAvailState": "power_avail_state", 
        "powerOnDeploy": "power_on_deploy", 
        "prio": "prio", 
        "profMethod": "prof_method", 
        "profiling": "profiling", 
        "psuCapacity": "psu_capacity", 
        "psuLineMode": "psu_line_mode", 
        "psuState": "psu_state", 
        "rn": "rn", 
        "scaledWt": "scaled_wt", 
        "status": "status", 
        "style": "style", 
        "updateTime": "update_time", 
        "weight": "weight", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_committed = None
        self.admin_fp_lock_state = None
        self.admin_peak = None
        self.admin_peak_new = None
        self.boot_power = None
        self.cap_action = None
        self.catalog_power = None
        self.ch_rsrvd_power = None
        self.child_action = None
        self.current_power = None
        self.dyn_realloc = None
        self.group_name = None
        self.idle_power = None
        self.max_power = None
        self.min_power = None
        self.oper_committed = None
        self.oper_fp_lock_state = None
        self.oper_min = None
        self.oper_peak = None
        self.oper_prof_method = None
        self.oper_state = None
        self.power_avail_state = None
        self.power_on_deploy = None
        self.prio = None
        self.prof_method = None
        self.profiling = None
        self.psu_capacity = None
        self.psu_line_mode = None
        self.psu_state = None
        self.scaled_wt = None
        self.status = None
        self.style = None
        self.update_time = None
        self.weight = None

        ManagedObject.__init__(self, "PowerBudget", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigImpactAnalyzer ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigImpactAnalyzerConsts():
    CONTEXT_DME = "dme"
    CONTEXT_IMPORT = "import"
    MODE_RELAY = "relay"
    MODE_STRAIGHT = "straight"
    REBOOT_REQUIRED_FALSE = "false"
    REBOOT_REQUIRED_NO = "no"
    REBOOT_REQUIRED_TRUE = "true"
    REBOOT_REQUIRED_YES = "yes"
    STATE_COMPLETE = "complete"
    STATE_NOT_STARTED = "not-started"
    STATE_TIMED_OUT = "timed-out"
    STATE_WATING = "wating"


class ConfigImpactAnalyzer(ManagedObject):
    """This is ConfigImpactAnalyzer class."""

    consts = ConfigImpactAnalyzerConsts()
    naming_props = set(['impactAnalyzerId'])

    mo_meta = MoMeta("ConfigImpactAnalyzer", "configImpactAnalyzer", "impact-analyzer-[impact_analyzer_id]", VersionMeta.Version111a, "InputOutput", 0x3ff, [], ["read-only"], ['configImpactAnalyzerEp'], ['configAppImpactResponse', 'configInputConfigSet', 'configManagedEpImpactResponse'], [None])

    prop_meta = {
        "ack_app_response_count": MoPropertyMeta("ack_app_response_count", "ackAppResponseCount", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "affected_chassis_cnt": MoPropertyMeta("affected_chassis_cnt", "affectedChassisCnt", "ushort", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "chassis_profile_affected": MoPropertyMeta("chassis_profile_affected", "chassisProfileAffected", "ushort", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "completion_timestamp": MoPropertyMeta("completion_timestamp", "completionTimestamp", "ulong", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, [], []), 
        "context": MoPropertyMeta("context", "context", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["dme", "import"], []), 
        "creation_timestamp": MoPropertyMeta("creation_timestamp", "creationTimestamp", "ulong", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "impact_analyzer_id": MoPropertyMeta("impact_analyzer_id", "impactAnalyzerId", "ulong", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x20, None, None, None, [], []), 
        "mode": MoPropertyMeta("mode", "mode", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["relay", "straight"], []), 
        "reboot_required": MoPropertyMeta("reboot_required", "rebootRequired", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "relay_app_response_count": MoPropertyMeta("relay_app_response_count", "relayAppResponseCount", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []), 
        "servers_affected": MoPropertyMeta("servers_affected", "serversAffected", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "service_profile_affected": MoPropertyMeta("service_profile_affected", "serviceProfileAffected", "ushort", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "service_profile_lost_visibility": MoPropertyMeta("service_profile_lost_visibility", "serviceProfileLostVisibility", "ushort", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "service_profile_suspend": MoPropertyMeta("service_profile_suspend", "serviceProfileSuspend", "ushort", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "service_profile_timed_out": MoPropertyMeta("service_profile_timed_out", "serviceProfileTimedOut", "ushort", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "source_connector_id": MoPropertyMeta("source_connector_id", "sourceConnectorId", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x100, None, None, None, ["complete", "not-started", "timed-out", "wating"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "uc_central_config_issues": MoPropertyMeta("uc_central_config_issues", "ucCentralConfigIssues", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "uc_central_errors": MoPropertyMeta("uc_central_errors", "ucCentralErrors", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "uc_central_overall_issues": MoPropertyMeta("uc_central_overall_issues", "ucCentralOverallIssues", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "uc_central_warnings": MoPropertyMeta("uc_central_warnings", "ucCentralWarnings", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "ucs_domains_affected": MoPropertyMeta("ucs_domains_affected", "ucsDomainsAffected", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "ucs_domains_analyzed": MoPropertyMeta("ucs_domains_analyzed", "ucsDomainsAnalyzed", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "ucs_domains_in_suspend": MoPropertyMeta("ucs_domains_in_suspend", "ucsDomainsInSuspend", "ushort", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "ucs_domains_lost_visibility": MoPropertyMeta("ucs_domains_lost_visibility", "ucsDomainsLostVisibility", "ushort", VersionMeta.Version121a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "ucs_domains_timed_out": MoPropertyMeta("ucs_domains_timed_out", "ucsDomainsTimedOut", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "ackAppResponseCount": "ack_app_response_count", 
        "affectedChassisCnt": "affected_chassis_cnt", 
        "chassisProfileAffected": "chassis_profile_affected", 
        "childAction": "child_action", 
        "completionTimestamp": "completion_timestamp", 
        "context": "context", 
        "creationTimestamp": "creation_timestamp", 
        "dn": "dn", 
        "impactAnalyzerId": "impact_analyzer_id", 
        "mode": "mode", 
        "rebootRequired": "reboot_required", 
        "relayAppResponseCount": "relay_app_response_count", 
        "rn": "rn", 
        "serversAffected": "servers_affected", 
        "serviceProfileAffected": "service_profile_affected", 
        "serviceProfileLostVisibility": "service_profile_lost_visibility", 
        "serviceProfileSuspend": "service_profile_suspend", 
        "serviceProfileTimedOut": "service_profile_timed_out", 
        "sourceConnectorId": "source_connector_id", 
        "state": "state", 
        "status": "status", 
        "ucCentralConfigIssues": "uc_central_config_issues", 
        "ucCentralErrors": "uc_central_errors", 
        "ucCentralOverallIssues": "uc_central_overall_issues", 
        "ucCentralWarnings": "uc_central_warnings", 
        "ucsDomainsAffected": "ucs_domains_affected", 
        "ucsDomainsAnalyzed": "ucs_domains_analyzed", 
        "ucsDomainsInSuspend": "ucs_domains_in_suspend", 
        "ucsDomainsLostVisibility": "ucs_domains_lost_visibility", 
        "ucsDomainsTimedOut": "ucs_domains_timed_out", 
    }

    def __init__(self, parent_mo_or_dn, impact_analyzer_id, **kwargs):
        self._dirty_mask = 0
        self.impact_analyzer_id = impact_analyzer_id
        self.ack_app_response_count = None
        self.affected_chassis_cnt = None
        self.chassis_profile_affected = None
        self.child_action = None
        self.completion_timestamp = None
        self.context = None
        self.creation_timestamp = None
        self.mode = None
        self.reboot_required = None
        self.relay_app_response_count = None
        self.servers_affected = None
        self.service_profile_affected = None
        self.service_profile_lost_visibility = None
        self.service_profile_suspend = None
        self.service_profile_timed_out = None
        self.source_connector_id = None
        self.state = None
        self.status = None
        self.uc_central_config_issues = None
        self.uc_central_errors = None
        self.uc_central_overall_issues = None
        self.uc_central_warnings = None
        self.ucs_domains_affected = None
        self.ucs_domains_analyzed = None
        self.ucs_domains_in_suspend = None
        self.ucs_domains_lost_visibility = None
        self.ucs_domains_timed_out = None

        ManagedObject.__init__(self, "ConfigImpactAnalyzer", parent_mo_or_dn, **kwargs)




"""This module contains the general information for VersionApplication ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class VersionApplicationConsts():
    pass


class VersionApplication(ManagedObject):
    """This is VersionApplication class."""

    consts = VersionApplicationConsts()
    naming_props = set([])

    mo_meta = MoMeta("VersionApplication", "versionApplication", "application", VersionMeta.Version101a, "InputOutput", 0xf, [], ["read-only"], ['versionEp'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "detail": MoPropertyMeta("detail", "detail", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "time": MoPropertyMeta("time", "time", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "version": MoPropertyMeta("version", "version", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "detail": "detail", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "time": "time", 
        "version": "version", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.detail = None
        self.status = None
        self.time = None
        self.version = None

        ManagedObject.__init__(self, "VersionApplication", parent_mo_or_dn, **kwargs)




"""This module contains the general information for PolicyScope ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class PolicyScopeConsts():
    RESOLVE_TYPE_NAME = "name"
    RESOLVE_TYPE_RN = "rn"


class PolicyScope(ManagedObject):
    """This is PolicyScope class."""

    consts = PolicyScopeConsts()
    naming_props = set(['policyType', 'resolveType', 'policyName'])

    mo_meta = MoMeta("PolicyScope", "policyScope", "scope-[policy_type]-[resolve_type]-[policy_name]", VersionMeta.Version201b, "InputOutput", 0x7f, [], ["read-only"], ['policyContext'], ['policyPolicyDestClass', 'policyRequestor'], ["get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "policy_name": MoPropertyMeta("policy_name", "policyName", "string", VersionMeta.Version201b, MoPropertyMeta.NAMING, 0x4, 1, 510, None, [], []), 
        "policy_type": MoPropertyMeta("policy_type", "policyType", "string", VersionMeta.Version201b, MoPropertyMeta.NAMING, 0x8, 1, 510, None, [], []), 
        "resolve_type": MoPropertyMeta("resolve_type", "resolveType", "string", VersionMeta.Version201b, MoPropertyMeta.NAMING, 0x10, None, None, None, ["name", "rn"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "policyName": "policy_name", 
        "policyType": "policy_type", 
        "resolveType": "resolve_type", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, policy_type, resolve_type, policy_name, **kwargs):
        self._dirty_mask = 0
        self.policy_type = policy_type
        self.resolve_type = resolve_type
        self.policy_name = policy_name
        self.child_action = None
        self.status = None

        ManagedObject.__init__(self, "PolicyScope", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FabricEthMonSrcRef ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FabricEthMonSrcRefConsts():
    SOURCE_TYPE_FCOEUPLINK_PORT = "fcoeuplink-port"
    SOURCE_TYPE_FCOEUPLINK_PORTCHANNEL = "fcoeuplink-portchannel"
    SOURCE_TYPE_HOST_PORT = "host-port"
    SOURCE_TYPE_NAS_PORT = "nas-port"
    SOURCE_TYPE_NAS_PORT_CHANNEL = "nas-port-channel"
    SOURCE_TYPE_PORT_CHANNEL = "port-channel"
    SOURCE_TYPE_SERVER_PORT = "server-port"
    SOURCE_TYPE_STORAGE = "storage"
    SOURCE_TYPE_UPLINK_PORT = "uplink-port"
    SOURCE_TYPE_VHBA = "vhba"
    SOURCE_TYPE_VLAN = "vlan"
    SOURCE_TYPE_VM_NIC = "vm-nic"
    SOURCE_TYPE_VNIC = "vnic"


class FabricEthMonSrcRef(ManagedObject):
    """This is FabricEthMonSrcRef class."""

    consts = FabricEthMonSrcRefConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("FabricEthMonSrcRef", "fabricEthMonSrcRef", "src-ref-[id]", VersionMeta.Version151a, "InputOutput", 0x1f, [], ["admin", "ext-lan-config", "ext-lan-policy"], ['fabricEthMon'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "ulong", VersionMeta.Version151a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "source_dn": MoPropertyMeta("source_dn", "sourceDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "source_type": MoPropertyMeta("source_type", "sourceType", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fcoeuplink-port", "fcoeuplink-portchannel", "host-port", "nas-port", "nas-port-channel", "port-channel", "server-port", "storage", "uplink-port", "vhba", "vlan", "vm-nic", "vnic"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|unknown|lan|san|ipc),){0,4}(defaultValue|unknown|lan|san|ipc){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "rn": "rn", 
        "sourceDn": "source_dn", 
        "sourceType": "source_type", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.source_dn = None
        self.source_type = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "FabricEthMonSrcRef", parent_mo_or_dn, **kwargs)




"""This module contains the general information for LicenseSource ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class LicenseSourceConsts():
    ALWAYS_USE_FALSE = "false"
    ALWAYS_USE_NO = "no"
    ALWAYS_USE_TRUE = "true"
    ALWAYS_USE_YES = "yes"


class LicenseSource(ManagedObject):
    """This is LicenseSource class."""

    consts = LicenseSourceConsts()
    naming_props = set([])

    mo_meta = MoMeta("LicenseSource", "licenseSource", "source", VersionMeta.Version111a, "InputOutput", 0xf, [], ["read-only"], ['licenseFile'], [], ["Get"])

    prop_meta = {
        "always_use": MoPropertyMeta("always_use", "alwaysUse", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "file_sku": MoPropertyMeta("file_sku", "fileSku", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "host_id": MoPropertyMeta("host_id", "hostId", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "host_name": MoPropertyMeta("host_name", "hostName", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "sku": MoPropertyMeta("sku", "sku", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "vendor_daemon_path": MoPropertyMeta("vendor_daemon_path", "vendorDaemonPath", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "alwaysUse": "always_use", 
        "childAction": "child_action", 
        "dn": "dn", 
        "fileSku": "file_sku", 
        "hostId": "host_id", 
        "hostName": "host_name", 
        "rn": "rn", 
        "sku": "sku", 
        "status": "status", 
        "vendorDaemonPath": "vendor_daemon_path", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.always_use = None
        self.child_action = None
        self.file_sku = None
        self.host_id = None
        self.host_name = None
        self.sku = None
        self.status = None
        self.vendor_daemon_path = None

        ManagedObject.__init__(self, "LicenseSource", parent_mo_or_dn, **kwargs)




"""This module contains the general information for BiosVProfile ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class BiosVProfileConsts():
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"
    REBOOT_ON_UPDATE_FALSE = "false"
    REBOOT_ON_UPDATE_NO = "no"
    REBOOT_ON_UPDATE_TRUE = "true"
    REBOOT_ON_UPDATE_YES = "yes"


class BiosVProfile(ManagedObject):
    """This is BiosVProfile class."""

    consts = BiosVProfileConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("BiosVProfile", "biosVProfile", "bios-prof-[name]", VersionMeta.Version111a, "InputOutput", 0x7f, [], ["read-only"], ['orgOrg'], ['biosTokenFeatureGroup', 'biosVfACPI10Support', 'biosVfASPMSupport', 'biosVfAllUSBDevices', 'biosVfAltitude', 'biosVfAssertNMIOnPERR', 'biosVfAssertNMIOnSERR', 'biosVfBootOptionRetry', 'biosVfCPUHardwarePowerManagement', 'biosVfCPUPerformance', 'biosVfCPUPowerManagement', 'biosVfConsistentDeviceNameControl', 'biosVfConsoleRedirection', 'biosVfCoreMultiProcessing', 'biosVfDDR3VoltageSelection', 'biosVfDRAMClockThrottling', 'biosVfDirectCacheAccess', 'biosVfDramRefreshRate', 'biosVfEnergyPerformanceTuning', 'biosVfEnhancedIntelSpeedStepTech', 'biosVfEnhancedPowerCappingSupport', 'biosVfExecuteDisableBit', 'biosVfFRB2Timer', 'biosVfFrequencyFloorOverride', 'biosVfFrontPanelLockout', 'biosVfIOEMezz1OptionROM', 'biosVfIOENVMe1OptionROM', 'biosVfIOENVMe2OptionROM', 'biosVfIOESlot1OptionROM', 'biosVfIOESlot2OptionROM', 'biosVfIntegratedGraphics', 'biosVfIntegratedGraphicsApertureSize', 'biosVfIntelEntrySASRAIDModule', 'biosVfIntelHyperThreadingTech', 'biosVfIntelTrustedExecutionTechnology', 'biosVfIntelTurboBoostTech', 'biosVfIntelVTForDirectedIO', 'biosVfIntelVirtualizationTechnology', 'biosVfInterleaveConfiguration', 'biosVfLocalX2Apic', 'biosVfLvDIMMSupport', 'biosVfMaxVariableMTRRSetting', 'biosVfMaximumMemoryBelow4GB', 'biosVfMemoryMappedIOAbove4GB', 'biosVfMirroringMode', 'biosVfNUMAOptimized', 'biosVfOSBootWatchdogTimer', 'biosVfOSBootWatchdogTimerPolicy', 'biosVfOSBootWatchdogTimerTimeout', 'biosVfOnboardGraphics', 'biosVfOnboardSATAController', 'biosVfOnboardStorage', 'biosVfOptionROMEnable', 'biosVfOptionROMLoad', 'biosVfOutOfBandManagement', 'biosVfPCHSATAMode', 'biosVfPCILOMPortsConfiguration', 'biosVfPCIROMCLP', 'biosVfPCISlotLinkSpeed', 'biosVfPCISlotOptionROMEnable', 'biosVfPOSTErrorPause', 'biosVfPSTATECoordination', 'biosVfPackageCStateLimit', 'biosVfProcessorC1E', 'biosVfProcessorC3Report', 'biosVfProcessorC6Report', 'biosVfProcessorC7Report', 'biosVfProcessorCMCI', 'biosVfProcessorCState', 'biosVfProcessorEnergyConfiguration', 'biosVfProcessorPrefetchConfig', 'biosVfQPILinkFrequencySelect', 'biosVfQPISnoopMode', 'biosVfQuietBoot', 'biosVfRedirectionAfterBIOSPOST', 'biosVfResumeOnACPowerLoss', 'biosVfSBMezz1OptionROM', 'biosVfSBNVMe1OptionROM', 'biosVfSIOC1OptionROM', 'biosVfSIOC2OptionROM', 'biosVfScrubPolicies', 'biosVfSelectMemoryRASConfiguration', 'biosVfSerialPortAEnable', 'biosVfSparingMode', 'biosVfSriovConfig', 'biosVfTPMPendingOperation', 'biosVfTPMSupport', 'biosVfTrustedPlatformModule', 'biosVfUCSMBootModeControl', 'biosVfUCSMBootOrderRuleControl', 'biosVfUEFIOSUseLegacyVideo', 'biosVfUSBBootConfig', 'biosVfUSBConfiguration', 'biosVfUSBFrontPanelAccessLock', 'biosVfUSBPortConfiguration', 'biosVfUSBSystemIdlePowerOptimizingSetting', 'biosVfVGAPriority', 'biosVfWorkloadConfiguration'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x2, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x8, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "reboot_on_update": MoPropertyMeta("reboot_on_update", "rebootOnUpdate", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["false", "no", "true", "yes"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "intId": "int_id", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rebootOnUpdate": "reboot_on_update", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.int_id = None
        self.policy_level = None
        self.policy_owner = None
        self.reboot_on_update = None
        self.status = None

        ManagedObject.__init__(self, "BiosVProfile", parent_mo_or_dn, **kwargs)




"""This module contains the general information for QueryImportContext ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class QueryImportContextConsts():
    ADMIN_STATE_IDLE = "idle"
    ADMIN_STATE_RESTART = "restart"
    IMPORT_ALL_FALSE = "false"
    IMPORT_ALL_NO = "no"
    IMPORT_ALL_TRUE = "true"
    IMPORT_ALL_YES = "yes"
    IS_RESOURCE_IMPORTED_FALSE = "false"
    IS_RESOURCE_IMPORTED_NO = "no"
    IS_RESOURCE_IMPORTED_TRUE = "true"
    IS_RESOURCE_IMPORTED_YES = "yes"
    OPERATION_ESTIMATE = "Estimate"
    OPERATION_IMPORT = "Import"
    QUERY_STATUS_FAILED = "failed"
    QUERY_STATUS_PENDING = "pending"
    QUERY_STATUS_SUCCESS = "success"
    QUERY_STATUS_TIMEOUT = "timeout"


class QueryImportContext(ManagedObject):
    """This is QueryImportContext class."""

    consts = QueryImportContextConsts()
    naming_props = set(['sessionId'])

    mo_meta = MoMeta("QueryImportContext", "queryImportContext", "import-[session_id]", VersionMeta.Version112a, "InputOutput", 0x3fff, [], ["admin"], ['queryEp'], ['faultInst', 'queryDependencyRef'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["idle", "restart"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version112a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x4, 0, 510, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "domain_id": MoPropertyMeta("domain_id", "domainId", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, [], []), 
        "impact_analyzer_dn": MoPropertyMeta("impact_analyzer_dn", "impactAnalyzerDn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "import_all": MoPropertyMeta("import_all", "importAll", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["false", "no", "true", "yes"], []), 
        "imported_name": MoPropertyMeta("imported_name", "importedName", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x40, 0, 510, None, [], []), 
        "is_resource_imported": MoPropertyMeta("is_resource_imported", "isResourceImported", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "operation": MoPropertyMeta("operation", "operation", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["Estimate", "Import"], []), 
        "policy_dest_dn": MoPropertyMeta("policy_dest_dn", "policyDestDn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x100, 0, 256, None, [], []), 
        "query_status": MoPropertyMeta("query_status", "queryStatus", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["failed", "pending", "success", "timeout"], []), 
        "resource_dest_dn": MoPropertyMeta("resource_dest_dn", "resourceDestDn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x200, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x400, 0, 256, None, [], []), 
        "session_id": MoPropertyMeta("session_id", "sessionId", "string", VersionMeta.Version112a, MoPropertyMeta.NAMING, 0x800, 1, 510, None, [], []), 
        "start_time": MoPropertyMeta("start_time", "startTime", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "status_description": MoPropertyMeta("status_description", "statusDescription", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "target_dn": MoPropertyMeta("target_dn", "targetDn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x2000, 0, 256, None, [], []), 
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "domainId": "domain_id", 
        "impactAnalyzerDn": "impact_analyzer_dn", 
        "importAll": "import_all", 
        "importedName": "imported_name", 
        "isResourceImported": "is_resource_imported", 
        "operation": "operation", 
        "policyDestDn": "policy_dest_dn", 
        "queryStatus": "query_status", 
        "resourceDestDn": "resource_dest_dn", 
        "rn": "rn", 
        "sessionId": "session_id", 
        "startTime": "start_time", 
        "status": "status", 
        "statusDescription": "status_description", 
        "targetDn": "target_dn", 
    }

    def __init__(self, parent_mo_or_dn, session_id, **kwargs):
        self._dirty_mask = 0
        self.session_id = session_id
        self.admin_state = None
        self.child_action = None
        self.descr = None
        self.domain_id = None
        self.impact_analyzer_dn = None
        self.import_all = None
        self.imported_name = None
        self.is_resource_imported = None
        self.operation = None
        self.policy_dest_dn = None
        self.query_status = None
        self.resource_dest_dn = None
        self.start_time = None
        self.status = None
        self.status_description = None
        self.target_dn = None

        ManagedObject.__init__(self, "QueryImportContext", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigFabricInterconnectFilter ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigFabricInterconnectFilterConsts():
    FAULT_LEVEL_CLEARED = "cleared"
    FAULT_LEVEL_CONDITION = "condition"
    FAULT_LEVEL_CRITICAL = "critical"
    FAULT_LEVEL_INFO = "info"
    FAULT_LEVEL_MAJOR = "major"
    FAULT_LEVEL_MINOR = "minor"
    FAULT_LEVEL_WARNING = "warning"
    FW_OPER_STATE_ACTIVATING = "activating"
    FW_OPER_STATE_BAD_IMAGE = "bad-image"
    FW_OPER_STATE_FAILED = "failed"
    FW_OPER_STATE_PENDING_NEXT_BOOT = "pending-next-boot"
    FW_OPER_STATE_READY = "ready"
    FW_OPER_STATE_REBOOTING = "rebooting"
    FW_OPER_STATE_SCHEDULED = "scheduled"
    FW_OPER_STATE_SET_STARTUP = "set-startup"
    FW_OPER_STATE_THROTTLED = "throttled"
    FW_OPER_STATE_UPDATING = "updating"
    FW_OPER_STATE_UPGRADING = "upgrading"


class ConfigFabricInterconnectFilter(ManagedObject):
    """This is ConfigFabricInterconnectFilter class."""

    consts = ConfigFabricInterconnectFilterConsts()
    naming_props = set([])

    mo_meta = MoMeta("ConfigFabricInterconnectFilter", "configFabricInterconnectFilter", "fabric-interconnect-filter", VersionMeta.Version131a, "InputOutput", 0x1fff, [], ["read-only"], [], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "domain_dn": MoPropertyMeta("domain_dn", "domainDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x4, 0, 256, None, [], []), 
        "domain_group_dn": MoPropertyMeta("domain_group_dn", "domainGroupDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, 0, 256, None, [], []), 
        "domain_name": MoPropertyMeta("domain_name", "domainName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "fault_level": MoPropertyMeta("fault_level", "faultLevel", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["cleared", "condition", "critical", "info", "major", "minor", "warning"], []), 
        "fw_oper_state": MoPropertyMeta("fw_oper_state", "fwOperState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x40, None, None, None, ["activating", "bad-image", "failed", "pending-next-boot", "ready", "rebooting", "scheduled", "set-startup", "throttled", "updating", "upgrading"], []), 
        "fw_service_pack_version": MoPropertyMeta("fw_service_pack_version", "fwServicePackVersion", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x80, 0, 510, None, [], []), 
        "fw_version": MoPropertyMeta("fw_version", "fwVersion", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x100, 0, 510, None, [], []), 
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x200, 0, 510, None, [], []), 
        "operability": MoPropertyMeta("operability", "operability", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x800, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "domainDn": "domain_dn", 
        "domainGroupDn": "domain_group_dn", 
        "domainName": "domain_name", 
        "faultLevel": "fault_level", 
        "fwOperState": "fw_oper_state", 
        "fwServicePackVersion": "fw_service_pack_version", 
        "fwVersion": "fw_version", 
        "model": "model", 
        "operability": "operability", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.domain_dn = None
        self.domain_group_dn = None
        self.domain_name = None
        self.fault_level = None
        self.fw_oper_state = None
        self.fw_service_pack_version = None
        self.fw_version = None
        self.model = None
        self.operability = None
        self.status = None

        ManagedObject.__init__(self, "ConfigFabricInterconnectFilter", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FirmwareExcludeServerComponent ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FirmwareExcludeServerComponentConsts():
    SERVER_COMPONENT_ADAPTOR = "adaptor"
    SERVER_COMPONENT_BLADE_BIOS = "blade-bios"
    SERVER_COMPONENT_BLADE_CONTROLLER = "blade-controller"
    SERVER_COMPONENT_BOARD_CONTROLLER = "board-controller"
    SERVER_COMPONENT_CPLD = "cpld"
    SERVER_COMPONENT_FLEXFLASH_CONTROLLER = "flexflash-controller"
    SERVER_COMPONENT_GRAPHICS_CARD = "graphics-card"
    SERVER_COMPONENT_HOST_HBA = "host-hba"
    SERVER_COMPONENT_HOST_HBA_OPTIONROM = "host-hba-optionrom"
    SERVER_COMPONENT_HOST_NIC = "host-nic"
    SERVER_COMPONENT_HOST_NIC_OPTIONROM = "host-nic-optionrom"
    SERVER_COMPONENT_INTEL_AMC = "intel-amc"
    SERVER_COMPONENT_LOCAL_DISK = "local-disk"
    SERVER_COMPONENT_NVME_MSWITCH = "nvme-mswitch"
    SERVER_COMPONENT_PERSISTENT_MEMORY_DIMM = "persistent-memory-dimm"
    SERVER_COMPONENT_PLX_SWITCH = "plx-switch"
    SERVER_COMPONENT_PSU = "psu"
    SERVER_COMPONENT_RETIMER = "retimer"
    SERVER_COMPONENT_SAS_EXP_REG_FW = "sas-exp-reg-fw"
    SERVER_COMPONENT_SAS_EXPANDER = "sas-expander"
    SERVER_COMPONENT_STORAGE_CONTROLLER = "storage-controller"
    SERVER_COMPONENT_STORAGE_CONTROLLER_ONBOARD_DEVICE = "storage-controller-onboard-device"
    SERVER_COMPONENT_STORAGE_CONTROLLER_ONBOARD_DEVICE_CPLD = "storage-controller-onboard-device-cpld"
    SERVER_COMPONENT_STORAGE_CONTROLLER_ONBOARD_DEVICE_PSOC = "storage-controller-onboard-device-psoc"
    SERVER_COMPONENT_STORAGE_DEV_BRIDGE = "storage-dev-bridge"
    SERVER_COMPONENT_UBM = "ubm"
    SERVER_COMPONENT_UNSPECIFIED = "unspecified"


class FirmwareExcludeServerComponent(ManagedObject):
    """This is FirmwareExcludeServerComponent class."""

    consts = FirmwareExcludeServerComponentConsts()
    naming_props = set(['serverComponent'])

    mo_meta = MoMeta("FirmwareExcludeServerComponent", "firmwareExcludeServerComponent", "exclude-server-component-[server_component]", VersionMeta.Version141a, "InputOutput", 0x1f, [], ["admin", "ls-compute", "ls-config-policy", "ls-server-policy"], ['firmwareComputeHostPack'], [], ["Add", "Get", "Remove"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "server_component": MoPropertyMeta("server_component", "serverComponent", "string", VersionMeta.Version141a, MoPropertyMeta.NAMING, 0x8, None, None, None, ["adaptor", "blade-bios", "blade-controller", "board-controller", "cpld", "flexflash-controller", "graphics-card", "host-hba", "host-hba-optionrom", "host-nic", "host-nic-optionrom", "intel-amc", "local-disk", "nvme-mswitch", "persistent-memory-dimm", "plx-switch", "psu", "retimer", "sas-exp-reg-fw", "sas-expander", "storage-controller", "storage-controller-onboard-device", "storage-controller-onboard-device-cpld", "storage-controller-onboard-device-psoc", "storage-dev-bridge", "ubm", "unspecified"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "serverComponent": "server_component", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, server_component, **kwargs):
        self._dirty_mask = 0
        self.server_component = server_component
        self.child_action = None
        self.status = None

        ManagedObject.__init__(self, "FirmwareExcludeServerComponent", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EquipmentBeaconLed ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentBeaconLedConsts():
    ADMIN_STATE_BLINKING = "blinking"
    ADMIN_STATE_ETH = "eth"
    ADMIN_STATE_FC = "fc"
    ADMIN_STATE_OFF = "off"
    ADMIN_STATE_ON = "on"
    COLOR_AMBER = "amber"
    COLOR_BLUE = "blue"
    COLOR_GREEN = "green"
    COLOR_RED = "red"
    COLOR_UNKNOWN = "unknown"
    OPER_STATE_BLINKING = "blinking"
    OPER_STATE_ETH = "eth"
    OPER_STATE_FC = "fc"
    OPER_STATE_OFF = "off"
    OPER_STATE_ON = "on"
    OPER_STATE_UNKNOWN = "unknown"


class EquipmentBeaconLed(ManagedObject):
    """This is EquipmentBeaconLed class."""

    consts = EquipmentBeaconLedConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentBeaconLed", "equipmentBeaconLed", "beacon", VersionMeta.Version112a, "InputOutput", 0x7f, [], ["admin", "pn-equipment", "pn-maintenance", "pn-policy"], ['computeBlade', 'computeRackUnit', 'computeServerUnit', 'equipmentChassis', 'equipmentFanModule', 'equipmentFex', 'equipmentIOCard', 'equipmentPsu'], [], ["Get"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["blinking", "eth", "fc", "off", "on"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version112a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "color": MoPropertyMeta("color", "color", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["amber", "blue", "green", "red", "unknown"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["blinking", "eth", "fc", "off", "on", "unknown"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version112a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version112a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "color": "color", 
        "dn": "dn", 
        "id": "id", 
        "name": "name", 
        "operState": "oper_state", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.admin_state = None
        self.child_action = None
        self.color = None
        self.id = None
        self.name = None
        self.oper_state = None
        self.status = None

        ManagedObject.__init__(self, "EquipmentBeaconLed", parent_mo_or_dn, **kwargs)




"""This module contains the general information for TestingSnmpSupport ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class TestingSnmpSupportConsts():
    pass


class TestingSnmpSupport(ManagedObject):
    """This is TestingSnmpSupport class."""

    consts = TestingSnmpSupportConsts()
    naming_props = set(['version'])

    mo_meta = MoMeta("TestingSnmpSupport", "testingSnmpSupport", "snmp-support-[version]", VersionMeta.Version101a, "InputOutput", 0x7f, [], ["admin", "read-only"], ['testingSnmpPolicy'], ['testingSnmpCommunity', 'testingSnmpTrap'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "port": MoPropertyMeta("port", "port", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["1-65535"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "sys_contact": MoPropertyMeta("sys_contact", "sysContact", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, 0, 510, None, [], []), 
        "sys_location": MoPropertyMeta("sys_location", "sysLocation", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, 0, 510, None, [], []), 
        "version": MoPropertyMeta("version", "version", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x40, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "port": "port", 
        "rn": "rn", 
        "status": "status", 
        "sysContact": "sys_contact", 
        "sysLocation": "sys_location", 
        "version": "version", 
    }

    def __init__(self, parent_mo_or_dn, version, **kwargs):
        self._dirty_mask = 0
        self.version = version
        self.child_action = None
        self.port = None
        self.status = None
        self.sys_contact = None
        self.sys_location = None

        ManagedObject.__init__(self, "TestingSnmpSupport", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FirmwareSystem ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FirmwareSystemConsts():
    OPER_STATE_FAILED = "failed"
    OPER_STATE_IN_PROGRESS = "in-progress"
    OPER_STATE_PENDING_USER_ACK = "pending-user-ack"
    OPER_STATE_READY = "ready"
    OPER_STATE_SCHEDULED = "scheduled"
    OPER_STATE_START_PENDING_EXT_PERMISSION = "start-pending-ext-permission"
    STATE_COMPATIBLE = "compatible"
    STATE_INCOMPATIBLE = "incompatible"
    STATE_MULTIPLE_RELEASES = "multiple-releases"
    STATE_SAME_RELEASE = "same-release"
    STATE_UNKNOWN = "unknown"


class FirmwareSystem(ManagedObject):
    """This is FirmwareSystem class."""

    consts = FirmwareSystemConsts()
    naming_props = set([])

    mo_meta = MoMeta("FirmwareSystem", "firmwareSystem", "fw-system", VersionMeta.Version101a, "InputOutput", 0xf, [], ["admin", "ls-config-policy", "ls-server-policy"], ['computeSystem', 'topSystem'], ['firmwareAck', 'firmwareInfra'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["failed", "in-progress", "pending-user-ack", "ready", "scheduled", "start-pending-ext-permission"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["compatible", "incompatible", "multiple-releases", "same-release", "unknown"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "operState": "oper_state", 
        "rn": "rn", 
        "state": "state", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.oper_state = None
        self.state = None
        self.status = None

        ManagedObject.__init__(self, "FirmwareSystem", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigInputConfigSet ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigInputConfigSetConsts():
    pass


class ConfigInputConfigSet(ManagedObject):
    """This is ConfigInputConfigSet class."""

    consts = ConfigInputConfigSetConsts()
    naming_props = set([])

    mo_meta = MoMeta("ConfigInputConfigSet", "configInputConfigSet", "InputConfigSet", VersionMeta.Version111a, "InputOutput", 0xf, [], ["read-only"], ['configImpactAnalyzer'], ['configInputConfig'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "created": MoPropertyMeta("created", "created", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "deleted": MoPropertyMeta("deleted", "deleted", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "modified": MoPropertyMeta("modified", "modified", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "created": "created", 
        "deleted": "deleted", 
        "dn": "dn", 
        "modified": "modified", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.created = None
        self.deleted = None
        self.modified = None
        self.status = None

        ManagedObject.__init__(self, "ConfigInputConfigSet", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FirmwareChassisComponentSpec ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FirmwareChassisComponentSpecConsts():
    EXCLUDE_BY_DEFAULT_FALSE = "false"
    EXCLUDE_BY_DEFAULT_NO = "no"
    EXCLUDE_BY_DEFAULT_TRUE = "true"
    EXCLUDE_BY_DEFAULT_YES = "yes"
    TYPE_CHASSIS_BOARD_CONTROLLER = "chassis-board-controller"
    TYPE_CMC = "cmc"
    TYPE_IOCARD = "iocard"
    TYPE_LOCAL_DISK = "local-disk"
    TYPE_SAS_EXPANDER = "sas-expander"
    TYPE_STORAGE_CONTROLLER = "storage-controller"
    TYPE_UNSPECIFIED = "unspecified"


class FirmwareChassisComponentSpec(ManagedObject):
    """This is FirmwareChassisComponentSpec class."""

    consts = FirmwareChassisComponentSpecConsts()
    naming_props = set(['type'])

    mo_meta = MoMeta("FirmwareChassisComponentSpec", "firmwareChassisComponentSpec", "chassis-component-spec-[type]", VersionMeta.Version151a, "InputOutput", 0x1f, [], [""], ['firmwareBundleTypeCapProvider'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "exclude_by_default": MoPropertyMeta("exclude_by_default", "excludeByDefault", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version151a, MoPropertyMeta.NAMING, 0x10, None, None, None, ["chassis-board-controller", "cmc", "iocard", "local-disk", "sas-expander", "storage-controller", "unspecified"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "excludeByDefault": "exclude_by_default", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, type, **kwargs):
        self._dirty_mask = 0
        self.type = type
        self.child_action = None
        self.exclude_by_default = None
        self.status = None

        ManagedObject.__init__(self, "FirmwareChassisComponentSpec", parent_mo_or_dn, **kwargs)




"""This module contains the general information for MgmtBackupPolicy ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class MgmtBackupPolicyConsts():
    ADMIN_STATE_DISABLE = "disable"
    ADMIN_STATE_ENABLE = "enable"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    POLICY_OWNER_UNSPECIFIED = "unspecified"
    PROTO_FTP = "ftp"
    PROTO_HTTP = "http"
    PROTO_NFS_COPY = "nfs-copy"
    PROTO_NONE = "none"
    PROTO_SCP = "scp"
    PROTO_SFTP = "sftp"
    PROTO_TFTP = "tftp"
    SCHEDULE_1DAY = "1day"
    SCHEDULE_1WEEK = "1week"
    SCHEDULE_2WEEK = "2week"
    SCHEDULE_STATUS_NOT_FOUND = "not-found"
    SCHEDULE_STATUS_UNKNOWN = "unknown"


class MgmtBackupPolicy(ManagedObject):
    """This is MgmtBackupPolicy class."""

    consts = MgmtBackupPolicyConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("MgmtBackupPolicy", "mgmtBackupPolicy", "db-backup-policy-[name]", VersionMeta.Version101a, "InputOutput", 0x7fff, [], ["admin", "operations"], ['orgDomainGroup', 'orgOrg', 'policyDeviceProfile'], ['faultInst', 'mgmtBackupTrigger'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["disable", "enable"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "host": MoPropertyMeta("host", "host", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""^$|^[a-zA-Z0-9][a-zA-Z0-9_.-]{0,63}$|^([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}$|^([0-9a-fA-F]{1,4}:){1,7}:$|^([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}$|^([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}$|^([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}$|^([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}$|^([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}$|^[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})$|^:((:[0-9a-fA-F]{1,4}){1,7}|:)$""", [], []), 
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]), 
        "last_backup": MoPropertyMeta("last_backup", "lastBackup", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "last_enabled_ts": MoPropertyMeta("last_enabled_ts", "lastEnabledTs", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "max_files": MoPropertyMeta("max_files", "maxFiles", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, [], ["1-1023"]), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "proto": MoPropertyMeta("proto", "proto", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["ftp", "http", "nfs-copy", "none", "scp", "sftp", "tftp"], []), 
        "pwd": MoPropertyMeta("pwd", "pwd", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x100, 0, 64, None, [], []), 
        "remote_file": MoPropertyMeta("remote_file", "remoteFile", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x200, 1, 128, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x400, 0, 256, None, [], []), 
        "sched_name": MoPropertyMeta("sched_name", "schedName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x800, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "schedule": MoPropertyMeta("schedule", "schedule", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, None, ["1day", "1week", "2week"], []), 
        "schedule_status": MoPropertyMeta("schedule_status", "scheduleStatus", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-found", "unknown"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "user": MoPropertyMeta("user", "user", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4000, 0, 510, None, [], []), 
    }

    prop_map = {
        "adminState": "admin_state", 
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "host": "host", 
        "intId": "int_id", 
        "lastBackup": "last_backup", 
        "lastEnabledTs": "last_enabled_ts", 
        "maxFiles": "max_files", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "proto": "proto", 
        "pwd": "pwd", 
        "remoteFile": "remote_file", 
        "rn": "rn", 
        "schedName": "sched_name", 
        "schedule": "schedule", 
        "scheduleStatus": "schedule_status", 
        "status": "status", 
        "user": "user", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.admin_state = None
        self.child_action = None
        self.descr = None
        self.host = None
        self.int_id = None
        self.last_backup = None
        self.last_enabled_ts = None
        self.max_files = None
        self.policy_level = None
        self.policy_owner = None
        self.proto = None
        self.pwd = None
        self.remote_file = None
        self.sched_name = None
        self.schedule = None
        self.schedule_status = None
        self.status = None
        self.user = None

        ManagedObject.__init__(self, "MgmtBackupPolicy", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FsmStatus ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FsmStatusConsts():
    STATE_FAIL = "fail"
    STATE_IN_PROGRESS = "inProgress"
    STATE_NOP = "nop"
    STATE_PENDING = "pending"
    STATE_SKIP = "skip"
    STATE_SUCCESS = "success"
    STATE_THROTTLED = "throttled"


class FsmStatus(ManagedObject):
    """This is FsmStatus class."""

    consts = FsmStatusConsts()
    naming_props = set(['convertedEpRef'])

    mo_meta = MoMeta("FsmStatus", "fsmStatus", "status-[converted_ep_ref]", VersionMeta.Version101a, "InputOutput", 0x7f, [], ["read-only"], ['computeSystem', 'topSystem'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "converted_ep_ref": MoPropertyMeta("converted_ep_ref", "convertedEpRef", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x2, 1, 510, None, [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "object_class_name": MoPropertyMeta("object_class_name", "objectClassName", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "remote_ep_ref": MoPropertyMeta("remote_ep_ref", "remoteEpRef", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "system_name": MoPropertyMeta("system_name", "systemName", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "convertedEpRef": "converted_ep_ref", 
        "descr": "descr", 
        "dn": "dn", 
        "name": "name", 
        "objectClassName": "object_class_name", 
        "remoteEpRef": "remote_ep_ref", 
        "rn": "rn", 
        "state": "state", 
        "status": "status", 
        "systemName": "system_name", 
    }

    def __init__(self, parent_mo_or_dn, converted_ep_ref, **kwargs):
        self._dirty_mask = 0
        self.converted_ep_ref = converted_ep_ref
        self.child_action = None
        self.descr = None
        self.name = None
        self.object_class_name = None
        self.remote_ep_ref = None
        self.state = None
        self.status = None
        self.system_name = None

        ManagedObject.__init__(self, "FsmStatus", parent_mo_or_dn, **kwargs)

